Schema and tooling for Copr fedora-messaging
============================================

Schemas for messages sent by Copr project, as described on
[fedora-messaging documentation page].

This package also provides several convenience methods for working with copr
messages, see docs.

[fedora-messaging documentation page]: https://fedora-messaging.readthedocs.io/en/latest/messages.html#schema
